@@ -3,7 +3,8 @@
 
 #include <ClanLib/core.h>
 #include "cadialog.h"
-#include "castringlist.h"
+#include <vector>
+#include <string>
 
 /** A simple info dialog. Shows a title and a text.
     @author Andrew Mustun
@@ -12,23 +13,23 @@ class CAInfoDialog : public CADialog  {
 public:
     enum InfoType { Info, Warning };
 
-    CAInfoDialog( const char* title,
-                  const char* text,
-                  InfoType type=Info,
+    CAInfoDialog( const std::string& title,
+                  const std::string& text,
+                  const InfoType type=Info,
                   bool modal=false,
                   CAScreen* screen=0 );
-    ~CAInfoDialog();
 
     virtual void buildScreen();
     virtual void on_key_released (const CL_InputEvent &key);
 
 private:
     //! Text list which contains the dialog text - one item is one line.
-    CAStringList textList;
+    std::vector<std::string> textList;
     //! Pointer to icon. Created and destroyed in this class.
     CL_Surface* icon;
     //! Type (Info, Warning).
     InfoType type;
 };
 
+
 #endif
