@@ -8,12 +8,12 @@
 */
 class CALabel : public CAWidget  {
 public:
-    CALabel( char* text, Alignment alignment, CL_Font* font );
+    CALabel( std::string text, Alignment alignment, CL_Font* font );
     ~CALabel();
 
     virtual void display( bool active=true );
     //! Sets a nwe text for this label.
-    void setText( const char* text ) {
+    void setText( const std::string text ) {
         this->text = text;
     }
 
