@@ -51,28 +51,30 @@ CAWidget::move( int x, int y ) {
 
 /** Resizes this widget.
     The new position depends also on the alignment.
+    -1 don't resize
 */
 void
-CAWidget::resize( int width, int height ) {
-    this->width = width;
-    this->height = height;
+CAWidget::resize( int width, int height )
+{
+    if (width != -1) this->width = width;
+    if (height != -1) this->height = height;
 
     switch( alignment ) {
     case Left:
-        right = left+width;
+        right = left+ this->width;
         break;
 
     case Right:
-        left = right-width;
+        left = right- this->width;
         break;
 
     case Center:
-        left = (left+right)/2 - width/2;
-        right = (left+right)/2 + width/2;
+        left = (left+right)/2 - this->width/2;
+        right = (left+right)/2 + this->width/2;
         break;
     }
 
-    bottom = top+height;
+    bottom = top + this->height;
 
 }
 
