@@ -459,7 +459,6 @@ Player::checkFunctionMap()
 
     int i;
     int px, py;
-    unsigned int r,g,b,a;
     unsigned int speedNibbleEdge=15;
 
     // Color below car edges:
@@ -476,7 +475,7 @@ Player::checkFunctionMap()
         // Get the function pixel under this edge:
         //
         CL_Color tmp = m_currentTrack->getFunctionalPixel( edge[i][0],edge[i][1] );
-        g = tmp.get_green();
+        unsigned int g = tmp.get_green();
 
         // Calculate speed reduction:
         //
@@ -530,10 +529,11 @@ Player::checkFunctionMap()
     if( !CA_APP->checkCoordinate( px,py ) ) return;
 
     CL_Color tmp = m_currentTrack->getFunctionalPixel( px,py );
-    r = tmp.get_red();
-    g = tmp.get_green();
-    b = tmp.get_blue();
-    a = tmp.get_alpha();
+    
+    //unsigned int r = tmp.get_red(); // unused yet
+    unsigned int g = tmp.get_green();
+    unsigned int b = tmp.get_blue();
+    // unsigned int a = tmp.get_alpha(); // unused yet
 
     // TODO : It seems to be the contrary (15=fast, ... 0 = slow) ?
     unsigned int speedNibble = (g&0xF0)>>4;   // Speed regulation (0=fast ... 15=slow)
